@@ -62,9 +62,6 @@ class BaseModelAPI(ABC):
 
         data = request.get_json()
 
-        # TODO delete
-        print(data)
-
         recursive_update(self.params, data)
 
         if 'metric' not in self.params:
@@ -80,7 +77,6 @@ class BaseModelAPI(ABC):
         pass
 
     def train(self):
-        """Load data, run training, and return result"""
         args = Arguments(self.params)
         if type(self.params['dataset']) == str:
             # Old format: single dataset file from /data/raw
@@ -98,19 +94,25 @@ class BaseModelAPI(ABC):
 
             elif len(dataset_files) == 2:
                 # Resamplers: [X_train, y_train] - resample training only
-                X_train = pd.read_csv(os.path.join("/data/interim", dataset_files[0])).to_numpy()
+                X_train = pd.read_csv(os.path.join("/data/interim", dataset_files[0]))
                 y_train = pd.read_csv(os.path.join("/data/interim", dataset_files[1])).to_numpy().ravel()
                 logging.info("Loading resampler data: X_train, y_train")
                 self.result = self.fit_train(args, X_train=X_train, y_train=y_train)
 
             elif len(dataset_files) == 4:
                 # Classifiers: [X_train, y_train, X_test, y_test]
-                X_train = pd.read_csv(os.path.join("/data/interim", dataset_files[0])).to_numpy()
+                X_train = pd.read_csv(os.path.join("/data/interim", dataset_files[0]))
                 y_train = pd.read_csv(os.path.join("/data/interim", dataset_files[1])).to_numpy().ravel()
-                X_test = pd.read_csv(os.path.join("/data/interim", dataset_files[2])).to_numpy()
+                X_test = pd.read_csv(os.path.join("/data/interim", dataset_files[2]))
                 y_test = pd.read_csv(os.path.join("/data/interim", dataset_files[3])).to_numpy().ravel()
                 logging.info("Loading classifier data: X_train, y_train, X_test, y_test")
-                self.result = self.fit_train(args, X_train, y_train, X_test, y_test)
+                self.result = self.fit_train(
+                    args,
+                    X_train=X_train,
+                    y_train=y_train,
+                    X_test=X_test,
+                    y_test=y_test,
+                )
 
             else:
                 raise ValueError(f"Invalid dataset format: expected 1 (imputers), 2 (resamplers), or 4 (classifiers) files, got {len(dataset_files)}")
@@ -123,7 +125,13 @@ class BaseModelAPI(ABC):
 
     def save_result(self):
         # Save main result (transformed X_train for imputers/resamplers)
-        result_path = os.path.join("/data/interim", self.params['dataset_name'], self.params['impute_file_name'])
+        result_file_name = self.params.get('result_file_name')
+        if not result_file_name:
+            result_file_name = self.params.get('impute_file_name')
+        if not result_file_name:
+            raise KeyError("result_file_name not provided in parameters")
+
+        result_path = os.path.join("/data/interim", self.params['dataset_name'], result_file_name)
         with open(result_path, 'wb') as f:
             pickle.dump(self.result, f)
 
@@ -140,7 +148,16 @@ class BaseModelAPI(ABC):
         # If transform_file is provided, load and transform that data
         if data and 'transform_file' in data:
             transform_file = data['transform_file']
-            impute_file_name = data.get('impute_file_name', self.params['impute_file_name'])
+            result_file_name = (
+                data.get('result_file_name')
+                or self.params.get('result_file_name')
+                or data.get('impute_file_name')
+                or self.params.get('impute_file_name')
+            )
+
+            if not result_file_name:
+                return jsonify({"error": "result_file_name not provided"}), 400
+
             transform_data_path = os.path.join("/data/interim", self.params['dataset_name'], transform_file)
 
             if os.path.exists(transform_data_path):
@@ -157,7 +174,7 @@ class BaseModelAPI(ABC):
                 transformed_result = self.transform(data=X_transform)
 
                 # Save the transformed result
-                result_path = os.path.join("/data/interim", self.params['dataset_name'], impute_file_name)
+                result_path = os.path.join("/data/interim", self.params['dataset_name'], result_file_name)
                 with open(result_path, 'wb') as f:
                     pickle.dump(transformed_result, f)
 
