@@ -8,7 +8,7 @@ import pandas as pd
 class RunHyperImpute(BaseTransformer):
     # TODO make model parameter work
 
-    def __init__(self, model="ii", data_folder=None, categorical_columns=None, impute_file_path=None, **imputer_kwargs):
+    def __init__(self, model="ii", data_folder=None, categorical_columns=None, result_file_path=None, **imputer_kwargs):
         if data_folder is None:
             raise ValueError("data_folder cannot be None")
 
@@ -30,8 +30,8 @@ class RunHyperImpute(BaseTransformer):
 
         self.model = model
         self.categorical_columns = categorical_columns
-        self.impute_file_path = impute_file_path
-        self.impute_file_name = os.path.basename(self.impute_file_path)
+        self.result_file_path = result_file_path
+        self.result_file_name = os.path.basename(self.result_file_path) if self.result_file_path else None
         self.imputer_kwargs = imputer_kwargs
 
     @cached_property
@@ -49,6 +49,5 @@ class RunHyperImpute(BaseTransformer):
             ],
             "categorical_columns": self.categorical_columns,
             "imputer_kwargs": self.imputer_kwargs,
-            "impute_file_name": self.impute_file_name
+            "result_file_name": self.result_file_name
         }
-
