@@ -2,6 +2,7 @@
 import time
 import json
 import os
+import pickle
 import docker
 import requests
 import pandas as pd
@@ -150,10 +151,13 @@ class BaseDockerModelClient(ABC):
         except docker.errors.NotFound:
             logging.info("[!] Container not found, skipping.")
 
-    def wait_for_api(self, timeout=60):
+    def wait_for_api(self, timeout=180):
         """
         Wait for the container's API to become responsive.
         Raise an error if the container exits or doesn't respond in time.
+
+        Args:
+            timeout: Maximum time to wait in seconds (default 180 for initial builds)
         """
         start_time = time.time()
         while time.time() - start_time < timeout:
@@ -208,6 +212,16 @@ class BaseDockerModelClient(ABC):
             else:
                 print(f"Container {self.container_name} is not running. Starting...")
                 container.start()
+                container.reload()
+                ports = container.attrs['NetworkSettings']['Ports']
+                internal = f"{self.container_port}/tcp"
+                host_info = ports.get(internal)
+                if host_info:
+                    self.host_port = int(host_info[0]['HostPort'])
+                    self.api_url = f"http://localhost:{self.host_port}"
+                    print(f"Reconnected container on port {self.host_port}")
+                else:
+                    raise RuntimeError("Could not find port mapping for the restarted container.")
 
         except docker.errors.NotFound:
             print("Container not found. Building and starting a new one...")
@@ -257,7 +271,7 @@ class BaseDockerModelClient(ABC):
         # Return list of filenames
         return [name for _, name in data_to_save]
 
-    def fit(self, args,  X_train, y_train=None, X_test=None, y_test=None):
+    def fit(self, args,  X_train, y_train=None, X_test=None, y_test=None, result_file_name=None, result_file_path=None):
         """
         Fit with training data.
 
@@ -286,7 +300,13 @@ class BaseDockerModelClient(ABC):
             headers = {"Content-Type": "application/json"}
 
             # Set parameters
-            response = requests.post(f"{self.api_url}/set", json=self.payload, headers=headers)
+            payload = self.payload.copy()
+            if result_file_name is not None:
+                payload["result_file_name"] = result_file_name
+            if result_file_path is not None:
+                payload["result_file_path"] = result_file_path
+
+            response = requests.post(f"{self.api_url}/set", json=payload, headers=headers)
             logging.debug("Parameters set")
 
             if response.status_code != 201:
@@ -298,11 +318,23 @@ class BaseDockerModelClient(ABC):
                 )
 
             # Train model
-            response = requests.post(f"{self.api_url}/train", json=self.payload, headers=headers)
+            response = requests.post(f"{self.api_url}/train", json=payload, headers=headers)
             logging.debug("Training complete")
             response.raise_for_status()
 
-            return response.json()
+            try:
+                api_result = response.json()
+            except ValueError:
+                api_result = None
+
+            if result_file_path and os.path.exists(result_file_path):
+                try:
+                    with open(result_file_path, "rb") as result_file:
+                        return pickle.load(result_file)
+                except Exception as load_error:
+                    logging.warning(f"Failed to load result file '{result_file_path}': {load_error}")
+
+            return api_result
 
         except requests.exceptions.RequestException as e:
             # Network/HTTP errors
