@@ -19,9 +19,10 @@ class BaseTransformer(BaseDockerModelClient):
     Note: Container stays alive across multiple transform() calls to avoid rebuild overhead.
     """
 
-    def __init__(self, *args, **kwargs):
-        # Set is_transformer=True so container stays running after fit()
-        super().__init__(*args, **kwargs, is_transformer=True)
+    def __init__(self, *args, keep_alive: bool = True, **kwargs):
+        # Set is_transformer flag based on keep_alive preference
+        super().__init__(*args, **kwargs, is_transformer=keep_alive)
+        self.keep_container_alive = keep_alive
 
     def transform(self, X, y=None):
         """
@@ -102,16 +103,28 @@ class BaseTransformer(BaseDockerModelClient):
 
             # Call the /transform endpoint
             headers = {"Content-Type": "application/json"}
+            result_artifact_path = getattr(self, "result_file_path", None)
+            if not result_artifact_path:
+                raise DockerContainerError(
+                    "Transformer missing result file path. Ensure result_file_path is provided during initialization.",
+                    container_id=self.container_id,
+                    image_name=self.image_name,
+                    operation="transform"
+                )
+
+            artifact_name = os.path.basename(result_artifact_path)
+            transform_artifact_name = artifact_name.replace('.p', '_transform.p')
+
             payload = {
                 "transform_file": transform_csv_name,
-                "impute_file_name": os.path.basename(self.impute_file_path).replace('.p', '_transform.p')
+                "result_file_name": transform_artifact_name
             }
 
             response = requests.post(f"{self.api_url}/transform", json=payload, headers=headers)
             response.raise_for_status()
 
             # Load the transformed result
-            result_path = self.impute_file_path.replace('.p', '_transform.p')
+            result_path = result_artifact_path.replace('.p', '_transform.p')
             with open(result_path, 'rb') as f:
                 result = pickle.load(f)
 
@@ -180,7 +193,7 @@ class BaseTransformer(BaseDockerModelClient):
         """
         self.cleanup()
 
-    def fit_resample(self, X, y):
+    def fit_resample(self, args, X, y):
         """
         Fit and resample the data (for resampler components).
 
@@ -198,12 +211,12 @@ class BaseTransformer(BaseDockerModelClient):
 
         try:
             # Call fit with both X and y
-            self.fit(self.args, X, y)
+            self.fit(args, X, y)
 
             # The resampler API should save both X and y resampled
             # Load them back from the saved files
-            impute_file_path_X = self.impute_file_path
-            impute_file_path_y = self.impute_file_path.replace('.p', '_y.p')
+            impute_file_path_X = self.result_file_path
+            impute_file_path_y = self.result_file_path.replace('.p', '_y.p')
 
             with open(impute_file_path_X, "rb") as f:
                 X_resampled = pickle.load(f)
