@@ -8,7 +8,7 @@ import os
 class RunSmoteSampler(BaseTransformer):
     # TODO make model parameter work
 
-    def __init__(self, model="rus", data_folder=None):
+    def __init__(self, model="rus", data_folder=None, result_file_path=None, **resampler_kwargs):
         if data_folder is None:
             raise ValueError("data_folder cannot be None")
 
@@ -27,26 +27,31 @@ class RunSmoteSampler(BaseTransformer):
                 "/var/run/docker.sock": "/var/run/docker.sock",  # give container full control of docker
             },  # mount current dir
             dockerfile_dir = os.path.dirname(os.path.abspath(__file__)),
+            keep_alive=False,
         )
+        self.model = model
+        self.result_file_path = result_file_path
+        self.result_file_name = os.path.basename(self.result_file_path) if self.result_file_path else None
+        self.resampler_kwargs = resampler_kwargs
 
     @property
     def payload(self):
-        # Get hyperparameters for this specific model (if provided)
-        hyperparams = None
+        # Get hyperparameters: first check args.hyperparams, then fall back to self.resampler_kwargs
+        resampler_params = self.resampler_kwargs  # From constructor
         if hasattr(self.args, 'hyperparams') and self.args.hyperparams:
-            # args.hyperparams is a dict: {'smote': {'k_neighbors': 7}, 'lr': {...}}
-            hyperparams = self.args.hyperparams.get(self.args.model, None)
+            # Override with hyperparams from args if provided
+            resampler_params = self.args.hyperparams.get(self.model, resampler_params)
 
         # Resamplers only work on training data to balance classes
         # Test data should NEVER be resampled - it must maintain real-world distribution
         return {
             "metric": self.args.metric,
-            "model": self.args.model,
+            "model": self.model,
             "dataset_name": self.args.dataset,  # Required for saving results
             "dataset": [
                 f"{self.args.dataset}/X_train_{self.container_name}.csv",
                 f"{self.args.dataset}/y_train_{self.container_name}.csv",
             ],
-            "params": hyperparams,  # Pass hyperparameters (or None for defaults)
+            "params": resampler_params,  # Pass hyperparameters
+            "result_file_name": self.result_file_name,
         }
-
