@@ -9,6 +9,14 @@ from ..pipelines.customclf import clfs
 from ..pipelines.customrsp import rsps
 from ..pipelines.customhbd import hbds
 from ..pipelines.customautoml import automls
+from ..pipelines.customsurvival import survival_models, survival_resamplers
+from ..pipelines.customunsupervised import (
+    clustering_models,
+    reduction_models,
+    anomaly_models,
+    survival_unsupervised_models,
+    unsupervised_models
+)
 from ..components.hybrids import RunAutoSmote
 from ..processing.utils import Result
 from ..processing.selectiontree import BinaryTree
@@ -48,6 +56,13 @@ class AutoImblearn:
         self.classifiers = list(clfs.keys())
         self.hybrids = list(hbds.keys())
         self.automls = list(automls.keys())
+        self.survival_models = list(survival_models.keys())
+        self.survival_resamplers = list(survival_resamplers.keys())
+        self.clustering_models = list(clustering_models.keys())
+        self.reduction_models = list(reduction_models.keys())
+        self.anomaly_models = list(anomaly_models.keys())
+        self.survival_unsupervised_models = list(survival_unsupervised_models.keys())
+        self.unsupervised_models = list(unsupervised_models.keys())
         self.imputers = imps
         self.run_pipe = run_pipe
         self.metric = metric
@@ -75,6 +90,36 @@ class AutoImblearn:
         result = self.run_pipe.fit(pipeline)
         return result
 
+    def _train_survival(self, pipeline):
+        """ Train the pipeline with survival (imputer, survival_resampler, survival_model) pipeline """
+        if len(pipeline) != 3:
+            raise ValueError("Pipeline {} length is not correct, not a survival method pipeline")
+        # Check if it's actually a survival pipeline
+        if pipeline[2] not in self.survival_models:
+            raise ValueError(f"Pipeline {pipeline} does not contain a survival model")
+        result = self.run_pipe.fit(pipeline)
+        return result
+
+    def _train_unsupervised(self, pipeline):
+        """ Train the pipeline with unsupervised (imputer, unsupervised_model) pipeline """
+        if len(pipeline) != 2:
+            raise ValueError("Pipeline {} length is not correct, not an unsupervised pipeline")
+        # Check if it's actually an unsupervised pipeline
+        if pipeline[1] not in self.unsupervised_models:
+            raise ValueError(f"Pipeline {pipeline} does not contain an unsupervised model")
+        result = self.run_pipe.fit(pipeline)
+        return result
+
+    def _train_survival_unsupervised(self, pipeline):
+        """ Train the pipeline with survival unsupervised (imputer, survival_unsupervised_model) pipeline """
+        if len(pipeline) != 2:
+            raise ValueError("Pipeline {} length is not correct, not a survival unsupervised pipeline")
+        # Check if it's actually a survival unsupervised pipeline
+        if pipeline[1] not in self.survival_unsupervised_models:
+            raise ValueError(f"Pipeline {pipeline} does not contain a survival unsupervised model")
+        result = self.run_pipe.fit(pipeline)
+        return result
+
     def _init_result_tree(self, result_tree: BinaryTree):
         imp = secrets.choice(self.imputers)
         result_tree.insert(imp, -1, "imp", "root")
@@ -229,9 +274,19 @@ class AutoImblearn:
                 # NEW evaluation
                 try:
                     if len(tmp_pipe) == 2:
-                        result = self._train_hybird(tmp_pipe)
+                        # Check if unsupervised
+                        if tmp_pipe[1] in self.survival_unsupervised_models:
+                            result = self._train_survival_unsupervised(tmp_pipe)
+                        elif tmp_pipe[1] in self.unsupervised_models:
+                            result = self._train_unsupervised(tmp_pipe)
+                        else:
+                            result = self._train_hybird(tmp_pipe)
                     elif len(tmp_pipe) == 3:
-                        result = self._train_regular(tmp_pipe)
+                        # Check if it's a survival pipeline
+                        if tmp_pipe[2] in self.survival_models:
+                            result = self._train_survival(tmp_pipe)
+                        else:
+                            result = self._train_regular(tmp_pipe)
                     else:
                         result = self._train_automl(tmp_pipe)
                 except Exception as e:
@@ -374,9 +429,19 @@ class AutoImblearn:
             if len(pipeline) == 1:
                 result = self._train_automl(pipeline)
             elif len(pipeline) == 2:
-                result = self._train_hybird(pipeline, args, 1.0)
+                # Check if unsupervised
+                if pipeline[1] in self.survival_unsupervised_models:
+                    result = self._train_survival_unsupervised(pipeline)
+                elif pipeline[1] in self.unsupervised_models:
+                    result = self._train_unsupervised(pipeline)
+                else:
+                    result = self._train_hybird(pipeline, args, 1.0)
             elif len(pipeline) == 3:
-                result = self._train_regular(pipeline)
+                # Check if it's a survival pipeline
+                if pipeline[2] in self.survival_models:
+                    result = self._train_survival(pipeline)
+                else:
+                    result = self._train_regular(pipeline)
             else:
                 raise Exception("Pipeline {} is not in the correct length".format(pipeline))
 
