@@ -433,6 +433,24 @@ class Pipeline(ABC):
         """
         pass
 
+    def cleanup(self) -> None:
+        """Release resources held by pipeline components (e.g., Docker containers)."""
+        get_components = getattr(self, "get_components", None)
+        if not callable(get_components):
+            return
+
+        for component in get_components().values():
+            if hasattr(component, "cleanup"):
+                try:
+                    component.cleanup()
+                except Exception as exc:
+                    import logging
+                    logging.getLogger(__name__).warning(
+                        "Failed to cleanup component %s: %s",
+                        type(component).__name__,
+                        exc,
+                    )
+
     def validate(self) -> bool:
         """
         Validate pipeline configuration and state.
