@@ -273,7 +273,7 @@ class PipelineFactory:
                     factory=lambda n=name: CustomImputer(
                         method=n,
                         data_folder=None,  # Set later if needed
-                        impute_file_path=None
+                        result_file_path=None
                     ),
                     description=f"{name} imputation method"
                 )
