@@ -140,21 +140,21 @@ class BasePipelineStrategy(ABC):
         Returns:
             Tuple of (X_train_imputed, X_test_imputed)
         """
-        impute_file_name = f"imp_{imp}_fold{self.args.repeat}.p"
-        impute_file_path = os.path.join(
+        result_file_name = f"imp_{imp}_fold{self.args.repeat}.p"
+        result_file_path = os.path.join(
             self.dataloader.get_interim_data_folder(),
             self.args.dataset,
-            impute_file_name
+            result_file_name
         )
-        impute_test_file_path = impute_file_path.replace('.p', '_test.p')
+        result_test_file_path = result_file_path.replace('.p', '_test.p')
 
         # Check if cached imputation results exist
-        if os.path.exists(impute_file_path) and os.path.exists(impute_test_file_path):
+        if os.path.exists(result_file_path) and os.path.exists(result_test_file_path):
             # Load cached results - no need to re-run imputation!
-            logging.info(f"\t Loading cached imputation from {impute_file_name}")
-            with open(impute_file_path, "rb") as f:
+            logging.info(f"\t Loading cached imputation from {result_file_name}")
+            with open(result_file_path, "rb") as f:
                 X_train_imputed = pickle.load(f)
-            with open(impute_test_file_path, "rb") as f:
+            with open(result_test_file_path, "rb") as f:
                 X_test_imputed = pickle.load(f)
             logging.info("\t Cached imputation loaded")
         else:
@@ -164,7 +164,7 @@ class BasePipelineStrategy(ABC):
                 method=imp,
                 data_folder=self.args.path,
                 dataset_name=self.args.dataset,
-                impute_file_path=impute_file_path
+                result_file_path=result_file_path
             )
 
             # Fit on train, transform both
@@ -208,22 +208,28 @@ class ThreeElementPipelineStrategy(BasePipelineStrategy):
         )
 
         # Resampling level - ONLY on training data
-        resamplar = CustomResamplar(X_train_imputed, y_train)
-        if resamplar.need_resample():
+        resamplar = CustomResamplar(
+            method=rsp,
+            data_folder=self.args.path
+        )
+        if resamplar.need_resample(y_train):
             logging.info("\t Re-Sampling Started")
-            X_train_imputed, y_train = resamplar.resample(self.args, rsp=rsp)
+            X_train_imputed, y_train = resamplar.fit_resample(self.args, X_train_imputed, y_train)
             logging.info("\t Re-Sampling Done")
 
         # Classification level
         logging.info(f"\t Training in fold {self.args.repeat} Start")
-        trainer = CustomClassifier(self.args)
-        trainer.train(X_train_imputed, y_train, clf=clf)
+        trainer = CustomClassifier(
+            method=clf,
+            data_folder=self.args.path,
+            metric=self.args.metric
+        )
+        trainer.fit(self.args, X_train_imputed, y_train)
         logging.info(f"\t Training in fold {self.args.repeat} Done")
 
         # Validation on imputed test data
-        trainer.predict(X_test_imputed, y_test)
+        result = trainer.score(X_test_imputed, y_test)
 
-        result = trainer.result
         del trainer
 
         return result
@@ -382,20 +388,27 @@ class SurvivalPipelineStrategy(BasePipelineStrategy):
         y_train_original = y_train.copy()
 
         # Survival resampling level - ONLY on training data
-        resamplar = CustomSurvivalResamplar(X_train_imputed, y_train)
-        if resamplar.need_resample():
+        resamplar = CustomSurvivalResamplar(
+            method=rsp,
+            data_folder=self.args.path
+        )
+        if resamplar.need_resample(y_train):
             logging.info("\t Survival Re-Sampling Started")
-            X_train_imputed, y_train = resamplar.resample(self.args, rsp=rsp)
+            X_train_imputed, y_train = resamplar.fit_resample(self.args, X_train_imputed, y_train)
             logging.info("\t Survival Re-Sampling Done")
 
         # Survival model training
         logging.info(f"\t Survival Training in fold {self.args.repeat} Start")
-        trainer = CustomSurvivalModel(self.args)
-        trainer.train(X_train_imputed, y_train, model=model)
+        trainer = CustomSurvivalModel(
+            method=model,
+            data_folder=self.args.path,
+            metric=self.args.metric
+        )
+        trainer.fit(self.args, X_train_imputed, y_train)
         logging.info(f"\t Survival Training in fold {self.args.repeat} Done")
 
         # Prediction and evaluation on test data
-        result = trainer.predict(X_test_imputed, y_test, Y_train=y_train_original)
+        result = trainer.score(X_test_imputed, y_test, y_train=y_train_original)
 
         del trainer
 
@@ -436,12 +449,16 @@ class UnsupervisedPipelineStrategy(BasePipelineStrategy):
 
         # Unsupervised model training
         logging.info(f"\t Training unsupervised model in fold {self.args.repeat} Start")
-        trainer = CustomUnsupervisedModel(self.args)
-        trainer.train(X_train_imputed, y_train, model=model)
+        trainer = CustomUnsupervisedModel(
+            method=model,
+            data_folder=self.args.path,
+            metric=self.args.metric
+        )
+        trainer.fit(self.args, X_train_imputed, y_train)
         logging.info(f"\t Training unsupervised model in fold {self.args.repeat} Done")
 
         # Prediction and evaluation on test data
-        result = trainer.predict(X_test_imputed, y_test)
+        result = trainer.score(X_test_imputed, y_test)
 
         del trainer
 
@@ -485,12 +502,16 @@ class SurvivalUnsupervisedPipelineStrategy(BasePipelineStrategy):
 
         # Survival unsupervised model training
         logging.info(f"\t Training survival unsupervised model in fold {self.args.repeat} Start")
-        trainer = CustomSurvivalUnsupervisedModel(self.args)
-        trainer.train(X_train_imputed, y_train, model=model)
+        trainer = CustomSurvivalUnsupervisedModel(
+            method=model,
+            data_folder=self.args.path,
+            metric=self.args.metric
+        )
+        trainer.fit(self.args, X_train_imputed, y_train)
         logging.info(f"\t Training survival unsupervised model in fold {self.args.repeat} Done")
 
         # Prediction and evaluation on test data
-        result = trainer.predict(X_test_imputed, y_test)
+        result = trainer.score(X_test_imputed, y_test)
 
         del trainer
 
