@@ -65,7 +65,7 @@ class CustomImputer(BaseEstimator, TransformerMixin):
                  registry:         Optional[Dict[str, Callable[..., Any]]] = None,
                  data_folder:      Optional[str] = None,
                  dataset_name:     Optional[str] = None,
-                 impute_file_path: Optional[str] = None,
+                 result_file_path: Optional[str] = None,
                  **imputer_kwargs: Any):
 
         self.method           = method
@@ -73,7 +73,7 @@ class CustomImputer(BaseEstimator, TransformerMixin):
         self.data_folder      = data_folder
         self.dataset_name     = dataset_name
         self.categorical_cols = None if categorical_cols is None else self.find_categorical(self.data_folder, dataset_name)
-        self.impute_file_path = impute_file_path
+        self.result_file_path = result_file_path
         self.imputer_kwargs   = dict(imputer_kwargs)
 
         self._impl            = self._build_impl()
@@ -95,7 +95,7 @@ class CustomImputer(BaseEstimator, TransformerMixin):
 
         # save imputed result if self._impl is not a docker model
         if not isinstance(self._impl, BaseTransformer):
-            self._save_imputed(X_imp, self.y)
+            self._save_result(X_imp, self.y)
 
         return X_imp
 
@@ -103,13 +103,19 @@ class CustomImputer(BaseEstimator, TransformerMixin):
         self.fit(args, X, y)
         return self.transform(X)
 
-    def __del__(self):
-        """Cleanup Docker containers when imputer is destroyed"""
-        if isinstance(self._impl, BaseTransformer):
-            try:
-                self._impl.cleanup()
-            except:
-                pass  # Ignore cleanup errors during deletion
+    def cleanup(self):
+        """Release any Docker resources held by the underlying implementation."""
+        impl = getattr(self, "_impl", None)
+        if impl and hasattr(impl, "cleanup"):
+            impl.cleanup()
+
+    # def __del__(self):
+    #     """Cleanup Docker containers when imputer is destroyed"""
+    #     if isinstance(self._impl, BaseTransformer):
+    #         try:
+    #             self._impl.cleanup()
+    #         except:
+    #             pass  # Ignore cleanup errors during deletion
 
     def get_params(self, deep: bool = True):
         params = {
@@ -168,7 +174,7 @@ class CustomImputer(BaseEstimator, TransformerMixin):
 
         # registry values are factories (lambda **kw)
         self.imputer_kwargs["data_folder"] = self.data_folder
-        self.imputer_kwargs["impute_file_path"] = self.impute_file_path
+        self.imputer_kwargs["result_file_path"] = self.result_file_path
         factory = self.registry[self.method]
         impl = factory(**self.imputer_kwargs)
 
@@ -180,13 +186,13 @@ class CustomImputer(BaseEstimator, TransformerMixin):
 
         return impl
 
-    def _save_imputed(self, X_imp, y):
+    def _save_result(self, X_imp, y):
         """Persist imputed result to data_folder"""
         if isinstance(X_imp, pd.DataFrame):
             data2save = (X_imp, y)
-            if not os.path.isdir(os.path.dirname(self.impute_file_path)):
-                os.makedirs(os.path.dirname(self.impute_file_path))
-            with open(self.impute_file_path, "wb") as f:
+            if not os.path.isdir(os.path.dirname(self.result_file_path)):
+                os.makedirs(os.path.dirname(self.result_file_path))
+            with open(self.result_file_path, "wb") as f:
                 pickle.dump(data2save, f)
 
         else:
